searchData={"items":[{"type":"module","title":"Unplug","doc":"The purpose of `Unplug` is to provide a wrapper around any arbitrary plug,\nwith the ability to conditionally execute that plug at run-time. The runtime\nconditions that are leveraged by `Unplug` must conform to the `Unplug.Predicate`\nbehaviour. Out of the box `Unplug` comes with predicates that can be used to\nexecute plugs based on:\n\n- Environment variable values\n- Application config values\n- Request header values\n- Request path values\n\n`Unplug` also preserves the behavior of `Plug` in that in its `init/1` function\nit will evaluate the `init/1` functions of your conditional plugs and store their\nvalues so that the `call/2` function does not have to reevaluate the `init/1`\nfunctions of your conditional plugs every time the plug pipeline is invoked (see\nthe `Plug` docs for more information https://hexdocs.pm/plug/Plug.Builder.html#module-options).\n\nTo use `Unplug`, add an entry in your `endpoint.ex` or `router.ex` files like\nso:\n\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.RequestPathIn, [\"/metrics\", \"healthcheck\"]}\n  do: {Plug.Telemetry, event_prefix: [:phoenix, :endpoint]}\n```","ref":"Unplug.html"},{"type":"module","title":"Unplug.Compose.All","doc":"Given a list of predicates, execute the plug if all of the predicates return\ntrue.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Compose.All, [\n    {Unplug.Predicates.AppConfigEquals, {:my_app, :some_config, :enabled}},\n    MyApp.CustomPredicate\n  ]},\n  do: MyApp.Plug\n```","ref":"Unplug.Compose.All.html"},{"type":"module","title":"Unplug.Compose.Any","doc":"Given a list of predicates, execute the plug if any of the predicates return\ntrue.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Compose.Any, [\n    {Unplug.Predicates.AppConfigEquals, {:my_app, :some_config, :enabled}},\n    MyApp.CustomPredicate\n  ]},\n  do: MyApp.Plug\n```","ref":"Unplug.Compose.Any.html"},{"type":"behaviour","title":"Unplug.Predicate","doc":"This behaviour defines the structure of a module that can be used\nas an Unplug filter.","ref":"Unplug.Predicate.html"},{"type":"callback","title":"Unplug.Predicate.call/2","doc":"The `call/1` function","ref":"Unplug.Predicate.html#c:call/2"},{"type":"module","title":"Unplug.Predicates.AppConfigEquals","doc":"Given an application and a key, execute the plug if the configured value\nmatches the expected value.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.AppConfigEquals, {:my_app, :some_config, :enabled}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.AppConfigEquals.html"},{"type":"module","title":"Unplug.Predicates.AppConfigIn","doc":"Given an application and a key, execute the plug if the configured value\nis in the provided enumerable of values.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.AppConfigIn, {:my_app, :some_config, [:enabled, :enabled_again]}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.AppConfigIn.html"},{"type":"module","title":"Unplug.Predicates.AppConfigNotEquals","doc":"Given an application and a key, do not execute the plug if the configured\nvalue matches the expected value.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.AppConfigNotEquals, {:my_app, :some_config, :disabled}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.AppConfigNotEquals.html"},{"type":"module","title":"Unplug.Predicates.AppConfigNotIn","doc":"Given an application and a key, execute the plug if the configured value\nis not in the provided enumerable of values.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.AppConfigNotIn, {:my_app, :some_config, [:enabled, :enabled_again]}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.AppConfigNotIn.html"},{"type":"module","title":"Unplug.Predicates.EnvVarEquals","doc":"Given an environment variable, execute the plug if the configured value\nmatches the expected value.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.EnvVarEquals, {\"ENABLE_DEBUG\", \"true\"}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.EnvVarEquals.html"},{"type":"module","title":"Unplug.Predicates.EnvVarIn","doc":"Given an environment variable, execute the plug if the environment\nvariable value is in the provided enumerable of values.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.EnvVarIn, {\"ENABLE_DEBUG\", [\"true\", \"1\"]}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.EnvVarIn.html"},{"type":"module","title":"Unplug.Predicates.EnvVarNotEquals","doc":"Given an environment variable, do not execute the plug if the configured\nvalue matches the expected value.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.EnvVarNotEquals, {\"ENABLE_DEBUG\", \"false\"}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.EnvVarNotEquals.html"},{"type":"module","title":"Unplug.Predicates.EnvVarNotIn","doc":"Given an environment variable, execute the plug if the environment\nvariable value is not in the provided enumerable of values.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.EnvVarNotIn, {\"ENABLE_DEBUG\", [\"true\", \"1\"]}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.EnvVarNotIn.html"},{"type":"module","title":"Unplug.Predicates.RequestHeaderEquals","doc":"Given a request header, execute the plug if the request value matches the\nexpected value.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.RequestHeaderEquals, {\"authorization\", \"super_secret\"}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.RequestHeaderEquals.html"},{"type":"module","title":"Unplug.Predicates.RequestHeaderNotEquals","doc":"Given a request header, do not execute the plug if the request value matches\nthe expected value.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.RequestHeaderNotEquals, {\"authorization\", \"super_secret\"}},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.RequestHeaderNotEquals.html"},{"type":"module","title":"Unplug.Predicates.RequestPathEquals","doc":"Given a request path, execute the plug if the request value matches the\nexpected value.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.RequestPathEquals, \"/metrics\"},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.RequestPathEquals.html"},{"type":"module","title":"Unplug.Predicates.RequestPathIn","doc":"Given a request path, execute the plug if the request value is in\nthe the provided enumerable of values.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.RequestPathIn, [\"/users\", \"/auth\"]},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.RequestPathIn.html"},{"type":"module","title":"Unplug.Predicates.RequestPathNotEquals","doc":"Given a request path, do not execute the plug if the request value\nmatches the expected value.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.RequestPathNotEquals, \"/metrics\"},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.RequestPathNotEquals.html"},{"type":"module","title":"Unplug.Predicates.RequestPathNotIn","doc":"Given a request path, do not execute the plug if the request value is\nin the the provided enumerable of values.\n\nUsage:\n```elixir\nplug Unplug,\n  if: {Unplug.Predicates.RequestPathNotIn, [\"/metrics\", \"/healthcheck\"]},\n  do: MyApp.Plug\n```","ref":"Unplug.Predicates.RequestPathNotIn.html"},{"type":"extras","title":"README","doc":"Conditionally execute your plug modules at run-time in your Phoenix/Plug applications! \n \n--------------------\n\n[![Hex.pm](https://img.shields.io/hexpm/v/unplug?style=for-the-badge)](http://hex.pm/packages/unplug)\n[![Build Status](https://img.shields.io/github/workflow/status/akoutmos/unplug/Unplug%20CI/master?label=Build%20Status&style=for-the-badge)](https://github.com/akoutmos/unplug/actions)\n[![Coverage Status](https://img.shields.io/coveralls/github/akoutmos/unplug/master?style=for-the-badge)](https://coveralls.io/github/akoutmos/prom_ex?branch=master)\n[![Support Unplug](https://img.shields.io/badge/Support%20Unplug-%E2%9D%A4-lightblue?style=for-the-badge)](https://github.com/sponsors/akoutmos)\n\n\n# Contents\n\n- [Installation](#installation)\n- [Supporting Unplug](#supporting-unplug)\n- [Setting Up Unplug](#setting-up-unplug)\n- [Attribution](#attribution)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"The package can be installed by adding `:unplug` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:unplug, \"~> 1.1.0\"}\n  ]\nend\n```\n\nAfter adding `:unplug` to your list of dependency, open up your `config/dev.exs` config file and\nadd the following:\n\n```elixir\n...\n\nconfig :unplug, :init_mode, :runtime\n\n...\n```\n\nThis will make it so that your plug `init/1` functions are not compiled for a quicker development\nexperience and is in line with Phoenix and Plug conventions.\n\nWith those in place, you are all set and ready to use Unplug","ref":"readme.html#installation"},{"type":"extras","title":"Supporting Unplug - README","doc":"If you rely on Unplug in your applications, it would much appreciated if you can give back to the\nproject in order to help ensure its continued development.\n\nCheckout my [GitHub Sponsorship page](https://github.com/sponsors/akoutmos) if you want to help out!","ref":"readme.html#supporting-unplug"},{"type":"extras","title":"Gold Sponsors - README","doc":"","ref":"readme.html#gold-sponsors"},{"type":"extras","title":"Silver Sponsors - README","doc":"","ref":"readme.html#silver-sponsors"},{"type":"extras","title":"Bronze Sponsors - README","doc":"","ref":"readme.html#bronze-sponsors"},{"type":"extras","title":"Setting Up Unplug - README","doc":"Unplug can be used anywhere you would typically use the `plug` macro. For example, let's say you want\nto skip the `Plug.Telemetry` plug for certain routes (to cut down on noise in your logs for example).\nTo do so, you would replace the following:\n\n```elixir\nplug Plug.Telemetry\n```\n\nwith the following:\n\n```elixir\nplug Unplug,\n    if: {Unplug.Predicates.RequestPathNotIn, [\"/metrics\", \"/healthcheck\"]},\n    do: {Plug.Telemetry, event_prefix: [:phoenix, :endpoint]}\n```\n\nor with the following if no configuration is required of `Plug.Telemetry`:\n\n```elixir\nplug Unplug,\n    if: {Unplug.Predicates.RequestPathNotIn, [\"/metrics\", \"/healthcheck\"]},\n    do: Plug.Telemetry\n```\n\nLet's break this down a bit so we can understand what is going on. `Unplug` takes a `KeywordList` of options\nthat specifies how it will evaluate the request.\n\nThe `:if` entry can be:\n\n- A tuple with the first element being the predicate module and the second element being the options to send to\n  the predicate (a predicate is a module that implements the `Unplug.Predicate` behavior).\n- A module that implements the `Unplug.Predicate` behavior. Without any predicate options being specified, an\n  empty list is sent as the second argument to the predicate's `call/2` function.\n\nThe `:do` entry can be:\n\n- A tuple where the first element is the plug module that you want to execute upon a truthy value from the\n  predicate, and the second element being options that you want to send to that plug.\n- A plug module that you want to execute upon a truthy value from the predicate. Without any options specified,\n  Unplug will assume that an empty list should be sent to the plug's `init/1` function.\n\nThere is also an `:else` entry that can be provided to `Unplug`. The `:else` entry is identical to the `:do` entry\nin terms of what it accepts as valid input. The `:else` entry is what is execute if the `:if` entry yields a falsey\nvalue for the current request.\n\nAn example to show off the `:else` functionality could be something like this:\n\n```elixir\nplug Unplug,\n  if: MyCoolApp.WhiteListedIPAddress,\n  do: MyCoolApp.MetricsExporter,\n  else: MyCoolApp.LogWarning\n```\n\nIf the above example, we only want to expose our Prometheus metrics if the request is coming from a known safe source\n(as a side note there are better ways to secure your metrics...don't use this in production).","ref":"readme.html#setting-up-unplug"},{"type":"extras","title":"Provided Predicates - README","doc":"Unplug provides the following predicates out of the box:\n\n| Predicate                                  | Description                                                                                                                   |\n| ------------------------------------------ | ----------------------------------------------------------------------------------------------------------------------------- |\n| `Unplug.Predicates.AppConfigEquals`        | Given an application and a key, execute the plug if the configured value matches the expected value                           |\n| `Unplug.Predicates.AppConfigNotEquals`     | Given an application and a key, do not execute the plug if the configured value matches the expected value                    |\n| `Unplug.Predicates.AppConfigIn`            | Given an application and a key, execute the plug if the configured value is in the provided enumerable of values              |\n| `Unplug.Predicates.AppConfigNotIn`         | Given an application and a key, execute the plug if the configured value is not in the provided enumerable of values          |\n| `Unplug.Predicates.EnvVarEquals`           | Given an environment variable, execute the plug if the configured value matches the expected value                            |\n| `Unplug.Predicates.EnvVarNotEquals`        | Given an environment variable, do not execute the plug if the configured value matches the expected value                     |\n| `Unplug.Predicates.EnvVarIn`               | Given an environment variable, execute the plug if the environment variable value is in the provided enumerable of values     |\n| `Unplug.Predicates.EnvVarNotIn`            | Given an environment variable, execute the plug if the environment variable value is not in the provided enumerable of values |\n| `Unplug.Predicates.RequestHeaderEquals`    | Given a request header, execute the plug if the request value matches the expected value                                      |\n| `Unplug.Predicates.RequestHeaderNotEquals` | Given a request header, do not execute the plug if the request value matches the expected value                               |\n| `Unplug.Predicates.RequestPathEquals`      | Given a request path, execute the plug if the request value matches the expected value                                        |\n| `Unplug.Predicates.RequestPathNotEquals`   | Given a request path, do not execute the plug if the request value matches the expected value                                 |\n| `Unplug.Predicates.RequestPathIn`          | Given a request path, execute the plug if the request value is in the provided enumerable of values                           |\n| `Unplug.Predicates.RequestPathNotIn`       | Given a request path, do not execute the plug if the request value is in the provided enumerable of values                    |","ref":"readme.html#provided-predicates"},{"type":"extras","title":"Writing Your Own Predicates - README","doc":"To write your own Unplug predicate, all you have to do is implement the `Unplug.Predicate` behavior and provide\na `call/2` function that will return a boolean value.\n\nFor example, if we wanted to have a plug conditionally execute only when the request method equals a certain value,\nwe could create the following predicate module:\n\n```elixir\ndefmodule MyApp.UnplugPredicates.MethodEquals do\n  @behaviour Unplug.Predicate\n\n  @impl true\n  def call(%Plug.Conn{method: req_method}, opt_method), do: req_method == opt_method\nend\n```\n\nand use it like so:\n\n```elixir\nplug Unplug,\n  if: {MyApp.UnplugPredicates.MethodEquals, \"DELETE\"},\n  do: MyApp.MyPlugs.DeleteAuditLoggerPlug\n```","ref":"readme.html#writing-your-own-predicates"},{"type":"extras","title":"Composition of predicates - README","doc":"Unplug supports composing multiple predicates together to create more complex conditions. For example, if you wanted\nto execute a plug only when a config key is set to a certain value and for a specific request path, you could do\nthe following:\n\n```elixir\nplug Unplug,\n  if: {Unplug.Compose.All, [\n    {Unplug.Predicates.AppConfigEquals, {:app, :config_key, :expected_value}},\n    {Unplug.Predicates.RequestPathEquals, \"/api/v1/users/1\"}\n  ]},\n  do: MyApp.MyPlugs.DeleteAuditLoggerPlug\n```\n\nUnplug provides the following composition predicates out of the box:\n\n| Predicate            | Description                                                                        |\n| -------------------- | ---------------------------------------------------------------------------------- |\n| `Unplug.Compose.All` | Given a list of predicates, execute the plug if all of the predicates return true. |\n| `Unplug.Compose.Any` | Given a list of predicates, execute the plug if any of the predicates return true. |","ref":"readme.html#composition-of-predicates"},{"type":"extras","title":"Attribution - README","doc":"- The logo for the project is an edited version of an SVG image from the [unDraw project](https://undraw.co/)","ref":"readme.html#attribution"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}